@@ -1,4 +1,4 @@
-from . import ResultMeta
+from .result_meta import ResultMeta
 
 
 class Result(ResultMeta):
